@@ -162,15 +162,26 @@ class TalismanDocument(AbstractTalismanDocument[_Content], Generic[_Content]):
     def __hash__(self):
         return hash((self._doc_id, self._content, self._metadata, self._facts, self._directives))
 
-    def get_facts_related2concept(self, concept_fact: ConceptFact, type_: Type[_Fact],
-                                  filter_: Callable[[_Fact], bool] = lambda _: True) -> Iterator[Union[ConceptFact, ValueFact]]:
-        for fact in chain(self.filter_facts(RelationFact), self.filter_facts(PropertyFact)):
+    def get_concept_related_concept(self, fact: ConceptFact, link_type_id: Optional[str] = None,
+                                    filter_: Callable[[_Fact], bool] = lambda _: True) -> Iterator[ConceptFact]:
+
+        for fact_ in self.filter_facts(RelationFact):
+            if link_type_id is not None and fact_.type_id != link_type_id:
+                continue
             related_fact = None
-            if fact.value.from_fact == concept_fact:
-                related_fact = fact.value.to_fact
+            if fact_.value.from_fact == fact:
+                related_fact = fact_.value.to_fact
 
-            elif fact.value.to_fact == concept_fact:
-                related_fact = fact.value.from_fact
+            elif fact_.value.to_fact == fact:
+                related_fact = fact_.value.from_fact
 
-            if isinstance(related_fact, type_) and filter_(related_fact):
+            if filter_(related_fact):
                 yield related_fact
+
+    def get_value_associated_via_property(self, fact: Union[ConceptFact, RelationFact], property_type_id: Optional[str] = None,
+                                          filter_: Callable[[_Fact], bool] = lambda _: True) -> Iterator[ValueFact]:
+        for fact_ in self.filter_facts(PropertyFact):
+            if property_type_id is not None and fact_.type_id != property_type_id:
+                continue
+            if fact_.value.from_fact == fact and filter_(fact_.value.to_fact):
+                yield fact_.value.to_fact
