@@ -1,3 +1,4 @@
+import logging
 from copy import deepcopy
 from typing import Iterable, Optional, Tuple, Union
 
@@ -5,13 +6,18 @@ from tdm.abstract.datamodel import AbstractFact, AbstractTalismanSpan, FactMetad
 
 ConceptValueType = str  # TODO: describe concept type
 
+logger = logging.getLogger(__name__)
 
-class ConceptFact(AbstractFact[str]):
+
+class ConceptFact(AbstractFact[ConceptValueType]):
     def __init__(self, id_: Optional[str], status: FactStatus, type_id: str,
-                 value: Optional[Union[str, Tuple[str, ...]]] = None,
+                 value: Union[ConceptValueType, Tuple[ConceptValueType, ...]] = tuple(),
                  mention: Optional[Iterable[AbstractTalismanSpan]] = None,
                  metadata: Optional[FactMetadata] = None):
         metadata = deepcopy(metadata)  # guarantee immutability
+        if value is None:
+            value = tuple()
+            logger.warning("value must not be None, value=tuple()")
         super().__init__(id_, FactType.CONCEPT, status, type_id, value, mention, metadata)
 
     def with_changes(self: 'ConceptFact', *, status: FactStatus = None, type_id: str = None,
